pub enum Received {
QueueEmpty,
Contacts,
Content(Box<Content>),
}Variants
QueueEmpty
when the receive loop is empty, happens when opening the websocket for the first time once you’re done synchronizing all pending messages for this registered client.
Contacts
Got contacts (only applies if linked to a primary device Contacts can be later queried in the store.
Content(Box<Content>)
Incoming decrypted message with metadata and content